==> dde-cooperation_1.1.2.tar.xz: BUILD/translations/dfmplugin-deliver/cooperation-transfer_kn_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kn_IN">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="60"/>
        <source>File transfer settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="62"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/menu/cooperationmenuscene.cpp" line="32"/>
        <source>File transfer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="55"/>
        <source>File transfer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="150"/>
        <source>File transfer settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="164"/>
        <source>Everyone in the same LAN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="165"/>
        <source>Only those who are collaborating are allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="166"/>
        <source>Not allow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="170"/>
        <source>Allows the following users to send files to me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>File save location</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-cooperation_1.1.13.tar.xz: BUILD/translations/dfmplugin-deliver/cooperation-transfer_kn_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kn_IN">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="60"/>
        <source>File transfer settings</source>
        <translation>ಸೂಚನೆ ಪರಿವರ್ತನೆ ಸೆಟ್ಟಿಂಗುಗಳು</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="62"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation>ಸೆಟ್ಟಿಂಗುಗಳು</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/menu/cooperationmenuscene.cpp" line="32"/>
        <source>File transfer</source>
        <translation>ಫೈಲ್ ಪರಿವರ್ತನೆ</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="55"/>
        <source>File transfer</source>
        <translation>ಫೈಲ್ ಪರಿವರ್ತನೆ</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="150"/>
        <source>File transfer settings</source>
        <translation>ಫೈಲ್ ಪರಿವರ್ತನೆ ಸೆಟ್ಟಿಂಗುಗಳು</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="164"/>
        <source>Everyone in the same LAN</source>
        <translation>ಸ್ವಲ್ಪ ಬಾರಿ ಸ್ವಲ್ಪ ಬಾರಿ ಸ್ವಲ್ಪ ಬಾರಿ LAN ನಲ್ಲಿರುವವರು</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="165"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>ನೀವು ಸಹಯೋಗ ಮಾಡುತ್ತಿರುವವರು ಮಾತ್ರ ಅನುಮತಿಸಲಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="166"/>
        <source>Not allow</source>
        <translation>ಅನುಮತಿಸದಿರಿ</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="170"/>
        <source>Allows the following users to send files to me</source>
        <translation>ನಿಮಗೆ ಈ ಕೆಳಗಿನ ಬಳಕೆದಾರರನ್ನು ಫೈಲ್ಗಳನ್ನು ಕಳುಹಿಸಲು ಅನುಮತಿಸುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>File save location</source>
        <translation>ಫೈಲ್ ಸೇವೆ ಸ್ಥಳ</translation>
    </message>
</context>
</TS>
